@@ -87,22 +87,22 @@ def decodePoolSwap(hex):
     variables = [
         {'key': 'from', 'type': 'address','endian':None},
         {'bytesCount':1, 'key': 'fromTokenId', 'type': int,'endian':None},
-        {'bytesCount': 8, 'key': 'fromAmount', 'type': int,'endian':'big'},
+        {'bytesCount': 8, 'key': 'fromAmount', 'type': int,'endian':'little'},
         {'key': 'to', 'type': 'address','endian':None},
         {'bytesCount':1, 'key': 'toTokenId', 'type': int,'endian':None},
-        {'bytesCount': 8, 'key': 'maxPriceCounter', 'type': int,'endian':'big'},
-        {'bytesCount': 8, 'key': 'maxPriceDenominator', 'type': int,'endian':'big'}
+        {'bytesCount': 8, 'key': 'maxPriceCounter', 'type': int,'endian':'little'},
+        {'bytesCount': 8, 'key': 'maxPriceDenominator', 'type': int,'endian':'little'}
     ]
     return searchHex(variables,hex)
 def decodePoolSwapV2(hex):
     variables = [
         {'key': 'from', 'type': 'address','endian':None},
         {'bytesCount':1, 'key': 'fromTokenId', 'type': int,'endian':None},
-        {'bytesCount': 8, 'key': 'fromAmount', 'type': int,'endian':'big'},
+        {'bytesCount': 8, 'key': 'fromAmount', 'type': int,'endian':'little'},
         {'key': 'to', 'type': 'address','endian':None},
         {'bytesCount':1, 'key': 'toTokenId', 'type': int,'endian':None},
-        {'bytesCount': 8, 'key': 'maxPriceCounter', 'type': int,'endian':'big'},
-        {'bytesCount': 8, 'key': 'maxPriceDenominator', 'type': int,'endian':'big'},
+        {'bytesCount': 8, 'key': 'maxPriceCounter', 'type': int,'endian':'little'},
+        {'bytesCount': 8, 'key': 'maxPriceDenominator', 'type': int,'endian':'little'},
         {'key':'pools', 'type':
             [{'bytesCount': 1, 'type': int,'endian':None}]
         }
@@ -124,14 +124,14 @@ def decodeRemovePoolLiquidity(hex):
     variables = [
         {'key': 'from', 'type': 'address','endian':None},
         {'bytesCount':1, 'key': 'tokenId', 'type': int,'endian':None},
-        {'bytesCount': 8, 'key': 'amount', 'type': int,'endian':'big'}
+        {'bytesCount': 8, 'key': 'amount', 'type': int,'endian':'little'}
     ]
     return searchHex(variables,hex)
 def decodeCreatePoolPair(hex):
     variables = [
         {'bytesCount':1, 'key': 'tokenIdA', 'type': int,'endian':None},
         {'bytesCount':1, 'key': 'tokenIdB', 'type': int,'endian':None},
-        {'bytesCount': 8, 'key': 'commission', 'type': int,'endian':'big'},
+        {'bytesCount': 8, 'key': 'commission', 'type': int,'endian':'little'},
         {'key': 'from', 'type': 'address','endian':None},
         {'bytesCount':1, 'key': 'status', 'type': int,'endian':None}
     ]
